==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/OperatorSelectorValueChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { OperatorSelectorValueChangedEventArgsDescription } from "./OperatorSelectorValueChangedEventArgsDescription";
/**
 * @hidden
 */
var OperatorSelectorValueChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(OperatorSelectorValueChangedEventArgsDescriptionMetadata, _super);
    function OperatorSelectorValueChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    OperatorSelectorValueChangedEventArgsDescriptionMetadata.b = function (a) {
        if (OperatorSelectorValueChangedEventArgsDescriptionMetadata.a == null) {
            OperatorSelectorValueChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            OperatorSelectorValueChangedEventArgsDescriptionMetadata.c(OperatorSelectorValueChangedEventArgsDescriptionMetadata.a);
        }
        if (a.j(OperatorSelectorValueChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(OperatorSelectorValueChangedEventArgsDescriptionMetadata.a);
    };
    OperatorSelectorValueChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("OldValue", "ExportedType:string:ColumnComparisonConditionOperatorType");
        a.item("OldValue@names", "Equals;NotEquals;LessThan;LessThanOrEqualTo;GreaterThan;GreaterThanOrEqualTo;Top;Bottom;TopPercentile;BottomPercentile;True;False;Contains;DoesNotContain;StartsWith;DoesNotStartWith;EndsWith;DoesNotEndWith;Today;Tomorrow;Yesterday;NextWeek;ThisWeek;LastWeek;NextMonth;ThisMonth;LastMonth;NextQuarter;ThisQuarter;LastQuarter;NextYear;ThisYear;LastYear;YearToDate;Q1;Q2;Q3;Q4;Month;Year;Empty;NotEmpty;IsNull;IsNotNull;Custom");
        a.item("NewValue", "ExportedType:string:ColumnComparisonConditionOperatorType");
        a.item("NewValue@names", "Equals;NotEquals;LessThan;LessThanOrEqualTo;GreaterThan;GreaterThanOrEqualTo;Top;Bottom;TopPercentile;BottomPercentile;True;False;Contains;DoesNotContain;StartsWith;DoesNotStartWith;EndsWith;DoesNotEndWith;Today;Tomorrow;Yesterday;NextWeek;ThisWeek;LastWeek;NextMonth;ThisMonth;LastMonth;NextQuarter;ThisQuarter;LastQuarter;NextYear;ThisYear;LastYear;YearToDate;Q1;Q2;Q3;Q4;Month;Year;Empty;NotEmpty;IsNull;IsNotNull;Custom");
    };
    OperatorSelectorValueChangedEventArgsDescriptionMetadata.d = function (a) {
        OperatorSelectorValueChangedEventArgsDescriptionMetadata.b(a);
        a.aa("OperatorSelectorValueChangedEventArgs", function () { return new OperatorSelectorValueChangedEventArgsDescription(); });
        a.z("OperatorSelectorValueChangedEventArgs", OperatorSelectorValueChangedEventArgsDescriptionMetadata.a);
    };
    OperatorSelectorValueChangedEventArgsDescriptionMetadata.$t = markType(OperatorSelectorValueChangedEventArgsDescriptionMetadata, 'OperatorSelectorValueChangedEventArgsDescriptionMetadata');
    OperatorSelectorValueChangedEventArgsDescriptionMetadata.a = null;
    return OperatorSelectorValueChangedEventArgsDescriptionMetadata;
}(Base));
export { OperatorSelectorValueChangedEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/OperatorSelectorValueChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { OperatorSelectorValueChangedEventArgsDescription } from "./OperatorSelectorValueChangedEventArgsDescription";
/**
 * @hidden
 */
var OperatorSelectorValueChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(OperatorSelectorValueChangedEventArgsDescriptionMetadata, _super);
    function OperatorSelectorValueChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    OperatorSelectorValueChangedEventArgsDescriptionMetadata.b = function (a) {
        if (OperatorSelectorValueChangedEventArgsDescriptionMetadata.a == null) {
            OperatorSelectorValueChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            OperatorSelectorValueChangedEventArgsDescriptionMetadata.c(OperatorSelectorValueChangedEventArgsDescriptionMetadata.a);
        }
        if (a.k(OperatorSelectorValueChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(OperatorSelectorValueChangedEventArgsDescriptionMetadata.a);
    };
    OperatorSelectorValueChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("OldValue", "ExportedType:string:ColumnComparisonConditionOperatorType");
        a.item("OldValue@names", "Equals;NotEquals;LessThan;LessThanOrEqualTo;GreaterThan;GreaterThanOrEqualTo;Top;Bottom;TopPercentile;BottomPercentile;True;False;Contains;DoesNotContain;StartsWith;DoesNotStartWith;EndsWith;DoesNotEndWith;Today;Tomorrow;Yesterday;NextWeek;ThisWeek;LastWeek;NextMonth;ThisMonth;LastMonth;NextQuarter;ThisQuarter;LastQuarter;NextYear;ThisYear;LastYear;YearToDate;Q1;Q2;Q3;Q4;Month;Year;Empty;NotEmpty;IsNull;IsNotNull;Custom");
        a.item("NewValue", "ExportedType:string:ColumnComparisonConditionOperatorType");
        a.item("NewValue@names", "Equals;NotEquals;LessThan;LessThanOrEqualTo;GreaterThan;GreaterThanOrEqualTo;Top;Bottom;TopPercentile;BottomPercentile;True;False;Contains;DoesNotContain;StartsWith;DoesNotStartWith;EndsWith;DoesNotEndWith;Today;Tomorrow;Yesterday;NextWeek;ThisWeek;LastWeek;NextMonth;ThisMonth;LastMonth;NextQuarter;ThisQuarter;LastQuarter;NextYear;ThisYear;LastYear;YearToDate;Q1;Q2;Q3;Q4;Month;Year;Empty;NotEmpty;IsNull;IsNotNull;Custom");
    };
    OperatorSelectorValueChangedEventArgsDescriptionMetadata.d = function (a) {
        OperatorSelectorValueChangedEventArgsDescriptionMetadata.b(a);
        a.ac("OperatorSelectorValueChangedEventArgs", function () { return new OperatorSelectorValueChangedEventArgsDescription(); });
        a.ab("OperatorSelectorValueChangedEventArgs", OperatorSelectorValueChangedEventArgsDescriptionMetadata.a);
    };
    OperatorSelectorValueChangedEventArgsDescriptionMetadata.$t = markType(OperatorSelectorValueChangedEventArgsDescriptionMetadata, 'OperatorSelectorValueChangedEventArgsDescriptionMetadata');
    OperatorSelectorValueChangedEventArgsDescriptionMetadata.a = null;
    return OperatorSelectorValueChangedEventArgsDescriptionMetadata;
}(Base));
export { OperatorSelectorValueChangedEventArgsDescriptionMetadata };
